@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -124,6 +127,42 @@ class ApiGatewayServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return ApiGatewayServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> ApiGatewayServiceTransport:
         """Returns the transport used by the client instance.
@@ -195,6 +234,26 @@ class ApiGatewayServiceAsyncClient:
     ) -> pagers.ListGatewaysAsyncPager:
         r"""Lists Gateways in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_list_gateways():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.ListGatewaysRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_gateways(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.ListGatewaysRequest, dict]):
                 The request object. Request message for
@@ -222,7 +281,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -275,6 +334,25 @@ class ApiGatewayServiceAsyncClient:
     ) -> apigateway.Gateway:
         r"""Gets details of a single Gateway.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_get_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.GetGatewayRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_gateway(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.GetGatewayRequest, dict]):
                 The request object. Request message for
@@ -295,15 +373,15 @@ class ApiGatewayServiceAsyncClient:
         Returns:
             google.cloud.apigateway_v1.types.Gateway:
                 A Gateway is an API-aware HTTP proxy.
-                It performs API-Method and/or API-
-                Consumer specific actions based on an
-                API Config such as authentication,
+                It performs API-Method and/or
+                API-Consumer specific actions based on
+                an API Config such as authentication,
                 policy enforcement, and backend
                 selection.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -353,6 +431,35 @@ class ApiGatewayServiceAsyncClient:
         r"""Creates a new Gateway in a given project and
         location.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_create_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                gateway = apigateway_v1.Gateway()
+                gateway.api_config = "api_config_value"
+
+                request = apigateway_v1.CreateGatewayRequest(
+                    parent="parent_value",
+                    gateway_id="gateway_id_value",
+                    gateway=gateway,
+                )
+
+                # Make the request
+                operation = client.create_gateway(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.CreateGatewayRequest, dict]):
                 The request object. Request message for
@@ -394,7 +501,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, gateway, gateway_id])
         if request is not None and has_flattened_params:
@@ -463,6 +570,32 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Gateway.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_update_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                gateway = apigateway_v1.Gateway()
+                gateway.api_config = "api_config_value"
+
+                request = apigateway_v1.UpdateGatewayRequest(
+                    gateway=gateway,
+                )
+
+                # Make the request
+                operation = client.update_gateway(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.UpdateGatewayRequest, dict]):
                 The request object. Request message for
@@ -500,7 +633,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([gateway, update_mask])
         if request is not None and has_flattened_params:
@@ -568,6 +701,29 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Gateway.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_delete_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.DeleteGatewayRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_gateway(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.DeleteGatewayRequest, dict]):
                 The request object. Request message for
@@ -605,7 +761,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -669,6 +825,26 @@ class ApiGatewayServiceAsyncClient:
     ) -> pagers.ListApisAsyncPager:
         r"""Lists Apis in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_list_apis():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.ListApisRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_apis(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.ListApisRequest, dict]):
                 The request object. Request message for
@@ -696,7 +872,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -749,6 +925,25 @@ class ApiGatewayServiceAsyncClient:
     ) -> apigateway.Api:
         r"""Gets details of a single Api.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_get_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.GetApiRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_api(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.GetApiRequest, dict]):
                 The request object. Request message for
@@ -773,7 +968,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -822,6 +1017,30 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Api in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_create_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.CreateApiRequest(
+                    parent="parent_value",
+                    api_id="api_id_value",
+                )
+
+                # Make the request
+                operation = client.create_api(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.CreateApiRequest, dict]):
                 The request object. Request message for
@@ -862,7 +1081,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, api, api_id])
         if request is not None and has_flattened_params:
@@ -931,6 +1150,28 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Api.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_update_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.UpdateApiRequest(
+                )
+
+                # Make the request
+                operation = client.update_api(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.UpdateApiRequest, dict]):
                 The request object. Request message for
@@ -967,7 +1208,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([api, update_mask])
         if request is not None and has_flattened_params:
@@ -1033,6 +1274,29 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Api.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_delete_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.DeleteApiRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_api(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.DeleteApiRequest, dict]):
                 The request object. Request message for
@@ -1070,7 +1334,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1134,6 +1398,26 @@ class ApiGatewayServiceAsyncClient:
     ) -> pagers.ListApiConfigsAsyncPager:
         r"""Lists ApiConfigs in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_list_api_configs():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.ListApiConfigsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_api_configs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.ListApiConfigsRequest, dict]):
                 The request object. Request message for
@@ -1161,7 +1445,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1214,6 +1498,25 @@ class ApiGatewayServiceAsyncClient:
     ) -> apigateway.ApiConfig:
         r"""Gets details of a single ApiConfig.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_get_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.GetApiConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_api_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.GetApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1239,7 +1542,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1289,6 +1592,31 @@ class ApiGatewayServiceAsyncClient:
         r"""Creates a new ApiConfig in a given project and
         location.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_create_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.CreateApiConfigRequest(
+                    parent="parent_value",
+                    api_config_id="api_config_id_value",
+                )
+
+                # Make the request
+                operation = client.create_api_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.CreateApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1328,7 +1656,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, api_config, api_config_id])
         if request is not None and has_flattened_params:
@@ -1397,6 +1725,28 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single ApiConfig.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_update_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.UpdateApiConfigRequest(
+                )
+
+                # Make the request
+                operation = client.update_api_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.UpdateApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1432,7 +1782,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([api_config, update_mask])
         if request is not None and has_flattened_params:
@@ -1500,6 +1850,29 @@ class ApiGatewayServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single ApiConfig.
 
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_delete_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.DeleteApiConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_api_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.DeleteApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1537,7 +1910,7 @@ class ApiGatewayServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
