@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -312,6 +314,73 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -362,50 +431,22 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, ApiGatewayServiceTransport):
             # transport is a ApiGatewayServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -417,6 +458,15 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -440,6 +490,27 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> pagers.ListGatewaysPager:
         r"""Lists Gateways in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_list_gateways():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.ListGatewaysRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_gateways(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.ListGatewaysRequest, dict]):
                 The request object. Request message for
@@ -467,7 +538,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -520,6 +591,26 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> apigateway.Gateway:
         r"""Gets details of a single Gateway.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_get_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.GetGatewayRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_gateway(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.GetGatewayRequest, dict]):
                 The request object. Request message for
@@ -540,15 +631,15 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         Returns:
             google.cloud.apigateway_v1.types.Gateway:
                 A Gateway is an API-aware HTTP proxy.
-                It performs API-Method and/or API-
-                Consumer specific actions based on an
-                API Config such as authentication,
+                It performs API-Method and/or
+                API-Consumer specific actions based on
+                an API Config such as authentication,
                 policy enforcement, and backend
                 selection.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -598,6 +689,36 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Creates a new Gateway in a given project and
         location.
 
+
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_create_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                gateway = apigateway_v1.Gateway()
+                gateway.api_config = "api_config_value"
+
+                request = apigateway_v1.CreateGatewayRequest(
+                    parent="parent_value",
+                    gateway_id="gateway_id_value",
+                    gateway=gateway,
+                )
+
+                # Make the request
+                operation = client.create_gateway(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.CreateGatewayRequest, dict]):
                 The request object. Request message for
@@ -639,7 +760,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, gateway, gateway_id])
         if request is not None and has_flattened_params:
@@ -699,6 +820,33 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single Gateway.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_update_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                gateway = apigateway_v1.Gateway()
+                gateway.api_config = "api_config_value"
+
+                request = apigateway_v1.UpdateGatewayRequest(
+                    gateway=gateway,
+                )
+
+                # Make the request
+                operation = client.update_gateway(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.UpdateGatewayRequest, dict]):
                 The request object. Request message for
@@ -736,7 +884,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([gateway, update_mask])
         if request is not None and has_flattened_params:
@@ -795,6 +943,30 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single Gateway.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_delete_gateway():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.DeleteGatewayRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_gateway(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.DeleteGatewayRequest, dict]):
                 The request object. Request message for
@@ -832,7 +1004,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -887,6 +1059,27 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> pagers.ListApisPager:
         r"""Lists Apis in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_list_apis():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.ListApisRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_apis(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.ListApisRequest, dict]):
                 The request object. Request message for
@@ -914,7 +1107,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -967,6 +1160,26 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> apigateway.Api:
         r"""Gets details of a single Api.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_get_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.GetApiRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_api(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.GetApiRequest, dict]):
                 The request object. Request message for
@@ -991,7 +1204,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1040,6 +1253,31 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new Api in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_create_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.CreateApiRequest(
+                    parent="parent_value",
+                    api_id="api_id_value",
+                )
+
+                # Make the request
+                operation = client.create_api(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.CreateApiRequest, dict]):
                 The request object. Request message for
@@ -1080,7 +1318,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, api, api_id])
         if request is not None and has_flattened_params:
@@ -1140,6 +1378,29 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single Api.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_update_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.UpdateApiRequest(
+                )
+
+                # Make the request
+                operation = client.update_api(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.UpdateApiRequest, dict]):
                 The request object. Request message for
@@ -1176,7 +1437,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([api, update_mask])
         if request is not None and has_flattened_params:
@@ -1233,6 +1494,30 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single Api.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_delete_api():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.DeleteApiRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_api(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.DeleteApiRequest, dict]):
                 The request object. Request message for
@@ -1270,7 +1555,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1325,6 +1610,27 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> pagers.ListApiConfigsPager:
         r"""Lists ApiConfigs in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_list_api_configs():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.ListApiConfigsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_api_configs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.ListApiConfigsRequest, dict]):
                 The request object. Request message for
@@ -1352,7 +1658,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1405,6 +1711,26 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> apigateway.ApiConfig:
         r"""Gets details of a single ApiConfig.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_get_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.GetApiConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_api_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.GetApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1430,7 +1756,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1480,6 +1806,32 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Creates a new ApiConfig in a given project and
         location.
 
+
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_create_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.CreateApiConfigRequest(
+                    parent="parent_value",
+                    api_config_id="api_config_id_value",
+                )
+
+                # Make the request
+                operation = client.create_api_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.CreateApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1519,7 +1871,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, api_config, api_config_id])
         if request is not None and has_flattened_params:
@@ -1579,6 +1931,29 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single ApiConfig.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_update_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.UpdateApiConfigRequest(
+                )
+
+                # Make the request
+                operation = client.update_api_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.UpdateApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1614,7 +1989,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([api_config, update_mask])
         if request is not None and has_flattened_params:
@@ -1673,6 +2048,30 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single ApiConfig.
 
+
+        .. code-block::
+
+            from google.cloud import apigateway_v1
+
+            def sample_delete_api_config():
+                # Create a client
+                client = apigateway_v1.ApiGatewayServiceClient()
+
+                # Initialize request argument(s)
+                request = apigateway_v1.DeleteApiConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_api_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.apigateway_v1.types.DeleteApiConfigRequest, dict]):
                 The request object. Request message for
@@ -1710,7 +2109,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
